@@ -8,7 +8,7 @@ from vstools import core, vs
 from ..abstract import Antialiaser, DoubleRater, SingleRater, SuperSampler, _Antialiaser
 
 __all__ = [
-    'SANGNOM', 'SangNom', 'SangNomSS', 'SangNomSR', 'SangNomDR'
+    'SangNom', 'SangNomDR'
 ]
 
 
@@ -26,7 +26,7 @@ class SANGNOM(_Antialiaser):
         return dict(aa=self.aa_strength, order=0 if self.double_fps else self.field + 1)
 
     def interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
-        interpolated = core.sangnom.SangNom(
+        interpolated: vs.VideoNode = core.sangnom.SangNom(  # type: ignore
             clip, dh=double_y or not self.drop_fields, **kwargs
         )
 
